%Script for solving the scalar conservation law in 1D with fractional
%diffusion of order alpha
clear
%Create your grid with N elements
N=50; %!NB! use ODD number !NB!
x=linspace(-10,10,N+1);
global delta
delta=abs(x(1)-x(2));
uspace=x(1,1:N)+delta/2;
global alpha
alpha=0.5;

%Create the amount of timesteps and an endtime
M=200;
tEnd=2;

%Find the CFL number
delt=tEnd/M;
CFLno=delt/delta;
disp(CFLno);
disp(delta);



%Create the Discretized Levy Matrix using numerical integration
Levy=0;
global LevyMatrix
if Levy
    LevyMatrix=-numLevy2(N,uspace);
else
    LevyMatrix=zeros(N);
end

%Create the weak initial condition vector
uwblock=weakIC(uspace,@block);
uwgauss=weakIC(uspace,@gauss);
uwsgn=weakIC(uspace,@sgn);
uwartan=weakIC(uspace,@artan);
uwsinus=weakIC(uspace,@sinus);
%Run your ODE-system solver
%Options for Solvers RKTVD, RK4 and fEuler
[t1,s1]=RKTVD(@LLFFlux, [0,tEnd], uwgauss,N,M);



figure; %Plotting the polynomial solution on each element
linGrid=zeros(N,100);
uh=zeros(N,100);
for i=1:N
    linGrid(i,:)=linspace(x(i),x(i+1));
    u0=s1(1,:);
    uh(i,:)=u0(i);
    hold on;
    plot(linGrid(i,:),uh(i,:),'g','LineWidth',1);
end

for i=1:N
    linGrid(i,:)=linspace(x(i),x(i+1));
    u0=s1(floor(1*M/4),:);
    uh(i,:)=u0(i);
    hold on;
    plot(linGrid(i,:),uh(i,:),'m','LineWidth',1);
end
for i=1:N
    linGrid(i,:)=linspace(x(i),x(i+1));
    u0=s1(floor(2*M/4),:);
    uh(i,:)=u0(i);
    hold on;
    plot(linGrid(i,:),uh(i,:),'b','LineWidth',1);
end
for i=1:N
    linGrid(i,:)=linspace(x(i),x(i+1));
    u0=s1(floor(3*M/4),:);
    uh(i,:)=u0(i);
    hold on;
    plot(linGrid(i,:),uh(i,:),'k','LineWidth',1);
end
for i=1:N
    linGrid(i,:)=linspace(x(i),x(i+1));
    u0=s1(floor(4*M/4),:);
    uh(i,:)=u0(i);
    hold on;
    plot(linGrid(i,:),uh(i,:),'r','LineWidth',1);
end

%Gauss Lobatto quadrature
%Different weights depending on the number of nodes
weights2=[1,1];
weights3=[1/3,4/3,1/3];
weights4=[1/6,5/6,5/6,1/6];
weights6=[1/15,(14-sqrt(7))/30,(14+sqrt(7))/30,(14+sqrt(7))/30,(14-sqrt(7))/30,1/15];

%Different sets of integration nodes
nodes2=[-1,1];
nodes3=[-1,0,1];
nodes4=[-1,-sqrt(1/5),sqrt(1/5),1];
nodes6=[-1,-sqrt((1/3)+(2*sqrt(7)/21)),-sqrt((1/3)-(2*sqrt(7)/21)),sqrt((1/3)-(2*sqrt(7)/21)),sqrt((1/3)+(2*sqrt(7)/21)),1];
converr=0;
for i=1:N
    for k=1:4
    converr=converr+(delta/2)*weights4(k)*abs(exactgauss((delta/2)*nodes4(k)+uspace(i))-s1(M,i));
    end
end
disp(converr);
title('N=201, CFL=0.5')
axis([-2,6,-0.1,1.1])